@@ -6,7 +6,7 @@
 #SBATCH --time=04:00:00                  # Time limit hrs:min:sec
 #SBATCH --output="{{ qspool::job_log_path }}/a=log+{{ qspool::qspool_job_name }}+slurm_job_id=%j+ext=.txt"
 
-__version__ = "0.2.6"
+__version__ = "0.3.2"
 __author__ = "Matthew Andres moreno"
 
 import argparse
@@ -18,6 +18,7 @@ import os
 import pathlib
 import re
 import shutil
+import socket
 import subprocess
 import sys
 import tempfile
@@ -56,13 +57,16 @@ job_log_path = instantiation_or_none(
     "{{ qspool::job_log_path }}",
 )
 queue_capacity = instantiation_or_none(
-    "{{ qspool::queue_capacity }}", apply=eval
+    "{{ qspool::queue_capacity }}", apply=int
 )
-qspool_job_title = instantiation_or_none(
-    "{{ qspool::qspool_job_title }}",
+qspooler_chain_depth = instantiation_or_none(
+    "{{ qspool::qspooler_chain_depth }}", apply=int
+)
+qspooler_job_title = instantiation_or_none(
+    "{{ qspool::qspooler_job_title }}",
 )
 this_script_template = instantiation_or_none(
-    r""" {{ qspool::this_script_template }} """,
+    r""" {{ qspool::this_script_template }} """,  # spaces prevent first/last "
     apply=lambda x: json.loads(x, strict=False),
 )
 
@@ -154,13 +158,16 @@ def is_at_least_1hr_job_time_remaining(start_time) -> bool:
 
 
 def make_qspool_job_name(
-    qspool_job_title: str,
+    qspooler_job_title: str,
     payload_job_scripts_list: typing.List[str],
+    qspooler_chain_depth: int,
 ) -> str:
-    return f"""what=qspool+payload_size={
+    return f"""what=qspooler+depth={
+        qspooler_chain_depth
+    }+payload_size={
         len(payload_job_scripts_list)
     }+title={
-        qspool_job_title
+        qspooler_job_title
     }"""
 
 
@@ -168,6 +175,7 @@ if __name__ == "__main__":
     logging.info(f"__version__={__version__}")
     start_time = time.time()
     logging.info(f"start_time={start_time}")
+    logging.info(f"hostname={socket.gethostname()}")
 
     if not is_this_script_instantiated():
         logging.info("running kickoff routine...")
@@ -204,9 +212,9 @@ if __name__ == "__main__":
             type=int,
         )
         parser.add_argument(
-            "--qspool-job_title",
-            default="spooler",
-            help="What title should be included in spool job name?",
+            "--qspooler-job-title",
+            default="none",
+            help="What title should be included in qspooler job names?",
             type=str,
         )
         args = parser.parse_args()
@@ -240,7 +248,8 @@ if __name__ == "__main__":
         job_log_path = os.path.expanduser(args.job_log_path)
         job_script_cc_path = os.path.expanduser(args.job_script_cc_path)
         queue_capacity = args.queue_capacity
-        qspool_job_title = args.qspool_job_title
+        qspooler_chain_depth = 0
+        qspooler_job_title = args.qspooler_job_title
 
     logging.info("running configuration setup and logging routine...")
 
@@ -255,8 +264,11 @@ if __name__ == "__main__":
     assert queue_capacity is not None
     logging.info(f"queue_capacity={queue_capacity}")
 
-    assert qspool_job_title is not None
-    logging.info(f"qspool_job_title={qspool_job_title}")
+    assert qspooler_chain_depth is not None
+    logging.info(f"qspooler_chain_depth={qspooler_chain_depth}")
+
+    assert qspooler_job_title is not None
+    logging.info(f"qspooler_job_title={qspooler_job_title}")
 
     if this_script_template is None:
         this_script_template = get_this_script_source()
@@ -304,12 +316,19 @@ if __name__ == "__main__":
             .replace(
                 "{{ qspool::qspool_job_name }}",
                 make_qspool_job_name(
-                    qspool_job_title, payload_job_script_contents_list
+                    qspooler_job_title,
+                    payload_job_script_contents_list,
+                    qspooler_chain_depth + 1
                 ),
                 2,
             )
             .replace("{{ qspool::queue_capacity }}", str(queue_capacity), 1)
-            .replace("{{ qspool::qspool_job_title }}", qspool_job_title, 1)
+            .replace("{{ qspool::qspooler_job_title }}", qspooler_job_title, 1)
+            .replace(
+                "{{ qspool::qspooler_chain_depth }}",
+                str(qspooler_chain_depth + 1),
+                1,
+            )
             .replace(
                 "{{ qspool::this_script_template }}",
                 json.dumps(this_script_template),
